objectStore.BdbObjectStore

|  | ## Cheshire3 Object Model: Class BdbObjectStore

Module objectStore :: Class BdbObjectStore

## Class BdbObjectStore
source code

Object Tree:

                   object --+
                            |
        configParser.C3Object --+
                                |
                      SimpleStore --+
                                    |
                   baseStore.BdbStore --+
                                        |
               object --+               |
                        |               |
    configParser.C3Object --+           |
                            |           |
                  ObjectStore --+       |
                                |       |
          baseObjects.RecordStore --+   |
                                    |   |
                    SimpleRecordStore --+
                                        |
               recordStore.BdbRecordStore --+
                                            |
                           object --+       |
                                    |       |
                configParser.C3Object --+   |
                                        |   |
                  baseObjects.ObjectStore --+
                                            |
                                           BdbObjectStore

Instance Methods

create_object(self, session, object=None) Given a Cheshire3 object, create a serialised form of it in the database.
delete_object(self, session, id) Delete an object.
fetch_object(self, session, id) Fetch an object.
fetch_objectList(self, session, req)
store_object(self, session, object) Store an object, potentially overwriting an existing copy.
Inherited from `recordStore.BdbRecordStore`: `__init__`, `__iter__` Inherited from `baseStore.BdbStore`: `begin_storing`, `clean`, `commit_storing`, `delete_item`, `fetch_checksum`, `fetch_data`, `fetch_idList`, `fetch_size`, `generate_id`, `get_dbsize`, `store_checkSum`, `store_data`, `verify_checkSum` Inherited from `baseStore.BdbStore` (private): `_closeContainer`, `_initialise`, `_openContainer`, `_verifyDatabase`, `_verifyDatabases` Inherited from `recordStore.SimpleRecordStore`: `create_record`, `delete_record`, `fetch_record`, `fetch_recordChecksum`, `fetch_recordSize`, `process_data`, `replace_record`, `store_record` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `baseStore.BdbStore`: `cxn`, `digestCxn`, `digestForId` Inherited from `baseStore.SimpleStore`: `currentId`, `idNormalizer` Inherited from `recordStore.SimpleRecordStore`: `inTransformer`, `outParser` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### create_object(self, session, object=None) | source code
Given a Cheshire3 object, create a serialised form of it in the database. Note: You should use create_record() as per RecordStore to create an object from a configuration. Overrides: baseObjects.ObjectStore.create_object (inherited documentation)

### delete_object(self, session, id) | source code
Delete an object. Overrides: baseObjects.ObjectStore.delete_object (inherited documentation)

### fetch_object(self, session, id) | source code
Fetch an object. Overrides: baseObjects.ObjectStore.fetch_object (inherited documentation)

### fetch_objectList(self, session, req) | source code

### store_object(self, session, object) | source code
Store an object, potentially overwriting an existing copy. Overrides: baseObjects.ObjectStore.store_object (inherited documentation)